# Artifacts

::: harborapi.client.HarborAsyncClient
    options:
        members:
        - get_artifact
        - copy_artifact
        - delete_artifact
        - get_artifact_vulnerabilities
        - get_artifact_build_history
        - get_artifact_accessories
        - get_artifact_tags
        - create_artifact_tag
        - delete_artifact_tag
        - add_artifact_label
        - delete_artifact_label
        - get_artifacts
